@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.h 540 2004-01-21 14:04:54Z markmc $
+    $Id: util.h 590 2008-05-20 07:53:53Z tml $
 
 ***************************************************************************/
 #ifndef __UTIL_H
@@ -87,7 +87,7 @@ extern void		__IDL_lex_cleanup 		(void);
 
 
 #ifndef HAVE_CPP_PIPE_STDIN
-extern char *				__IDL_tmp_filename;
+extern const char *			__IDL_tmp_filename;
 #endif
 extern const char *			__IDL_real_filename;
 extern char *				__IDL_cur_filename;
